@@ -169,6 +169,7 @@ def __execute__(
 			return lines
 
 	# create process.
+	if isinstance(command, str): command = command.split(' ')
 	p = subprocess.Popen(
 		command, 
 		shell=shell,
@@ -204,11 +205,30 @@ def __execute__(
 	return output
 
 # execute a shell script.
-def __execute_script__(script=""):
+def __execute_script__(
+	# the script in string.
+	script="",
+	# wait till the command is pinished. 
+	wait=False,
+	# the commands timeout, [timeout] overwrites parameter [wait].
+	timeout=None, 
+	# the commands output return format: string / array.
+	return_format="string", 
+	# the subprocess.Popen.shell argument.
+	shell=False,
+	# pass a input string to the process.
+	input=None,
+):
 	path = "/tmp/shell_script.sh"
-	__save_file__(path, script)
+	__save_bytes__(path, script.encode())
 	__set_file_path_permission__(path,permission=755)
-	output = __execute__(command=["sh", path])
+	output = __execute__(
+		command=[f"sh {path}"],
+		wait=wait,
+		timeout=timeout, 
+		return_format=return_format, 
+		shell=shell,
+		input=input,)
 	__delete_file_path__(path, forced=True)
 	return output
 
